=======
History
=======

0.1.1 (2022-04-28)
------------------
* added scene property to render objects available from python
* updated to radiance db4988bb 2022-04-24

0.1.0 (2022-04-14)
------------------

* split from main raytraverse module.
